@@ -247,7 +247,7 @@ class Crp:
         # Get customer ids
         customers = train_df['customerid'].unique()
         # Get the date which acts as reference point for future calculations
-        dateFlag_sep = np.max(org_df['order_date']) - pd.DateOffset(days=timeFlag)
+        dateFlag_sep = np.max(df['order_date']) - pd.DateOffset(days=timeFlag)
         # The date which is the min date for the feature matrix 
         date_flag_min = dateFlag_sep - pd.DateOffset(days=train_window)
         # Create a grouping aggregator
@@ -343,7 +343,7 @@ class Crp:
         """
         Params:
             original_dataset - > the original raw data 
-            lag              - > size ( in months) of the targetValue window
+            lag              - > size ( in days) of the targetValue window
             train_window     - > size of the feature matrix
         Output: Constructed dataframe 
         
